@@ -250,6 +250,39 @@ def _get_http_headers(user_agent=None, referer=None, accept_language=None):
     return headers
 
 
+def _get_host_by_name(host):
+    """
+    Resolve IP address from host using Google's public API for DNS over HTTPS.
+
+    Necessary fallback as socket.gethostbyname will not always work when using
+    a proxy. See https://developers.google.com/speed/public-dns/docs/doh/json
+
+    Parameters
+    ----------
+    host : string
+        the host to consistently resolve the IP address of
+
+    Returns
+    -------
+    ip_address : string
+        resolved IP address
+    """
+    dns_url = f"https://dns.google/resolve?name={host}"
+    response = requests.get(dns_url)
+    data = response.json()
+
+    # status = 0 means NOERROR: standard DNS response code
+    if response.ok and data["Status"] == 0:
+        ip_address = data["Answer"][0]["data"]
+        utils.log(f"Google resolved '{host}' to '{ip_address}'")
+        return ip_address
+
+    # in case host could not be resolved return the host itself
+    else:
+        utils.log(f"Google could not resolve '{host}'. Response status: {data['Status']}")
+        return host
+
+
 def _config_dns(url):
     """
     Force socket.getaddrinfo to use IP address instead of host.
@@ -277,7 +310,12 @@ def _config_dns(url):
     None
     """
     host = urlparse(url).netloc.split(":")[0]
-    ip = socket.gethostbyname(host)
+    try:
+        ip = socket.gethostbyname(host)
+    except socket.gaierror:  # pragma: no cover
+        # this error occurs sometimes when using a proxy. instead, you must
+        # get IP address using google's public JSON API for DNS over HTTPS
+        ip = _get_host_by_name(host)[0]
 
     def _getaddrinfo(*args):
         if args[0] == host:
@@ -294,13 +332,13 @@ def _get_pause(base_endpoint, recursive_delay=5, default_duration=60):
     Get a pause duration from the Overpass API status endpoint.
 
     Check the Overpass API status endpoint to determine how long to wait until
-    the next slot is available. You can disable this via the `ox.config`
-    function's `overpass_rate_limit` argument.
+    the next slot is available. You can disable this via the `settings`
+    module's `overpass_rate_limit` setting.
 
     Parameters
     ----------
     base_endpoint : string
-        base Overpass API endpoint (without "/status" at the end)
+        base Overpass API url (without "/status" at the end)
     recursive_delay : int
         how long to wait between recursive calls if the server is currently
         running a query
@@ -315,17 +353,19 @@ def _get_pause(base_endpoint, recursive_delay=5, default_duration=60):
         # if overpass rate limiting is False, then there is zero pause
         return 0
 
+    sc = None
+
     try:
         url = base_endpoint.rstrip("/") + "/status"
-        response = requests.get(url, headers=_get_http_headers())
-        status = response.text.split("\n")[3]
+        response = requests.get(url, headers=_get_http_headers(), **settings.requests_kwargs)
+        sc = response.status_code
+        status = response.text.split("\n")[4]
         status_first_token = status.split(" ")[0]
 
     except Exception:  # pragma: no cover
         # if we cannot reach the status endpoint or parse its output, log an
         # error and return default duration
-        sc = response.status_code
-        utils.log(f"Unable to query {url} got status {sc}", level=lg.ERROR)
+        utils.log(f"Unable to query {url}, got status {sc}", level=lg.ERROR)
         return default_duration
 
     try:
@@ -627,8 +667,12 @@ def nominatim_request(params, request_type="search", pause=1, error_pause=60):
     if request_type not in {"search", "reverse", "lookup"}:  # pragma: no cover
         raise ValueError('Nominatim request_type must be "search", "reverse", or "lookup"')
 
+    # resolve url to same IP even if there is server round-robin redirecting
+    _config_dns(settings.nominatim_endpoint.rstrip("/"))
+
     # prepare Nominatim API URL and see if request already exists in cache
     url = settings.nominatim_endpoint.rstrip("/") + "/" + request_type
+
     prepared_url = requests.Request("GET", url, params=params).prepare().url
     cached_response_json = _retrieve_from_cache(prepared_url)
 
@@ -647,7 +691,13 @@ def nominatim_request(params, request_type="search", pause=1, error_pause=60):
         # transmit the HTTP GET request
         utils.log(f"Get {prepared_url} with timeout={settings.timeout}")
         headers = _get_http_headers()
-        response = requests.get(url, params=params, timeout=settings.timeout, headers=headers)
+        response = requests.get(
+            url,
+            params=params,
+            timeout=settings.timeout,
+            headers=headers,
+            **settings.requests_kwargs,
+        )
         sc = response.status_code
 
         # log the response size and domain
@@ -720,7 +770,9 @@ def overpass_request(data, pause=None, error_pause=60):
         # transmit the HTTP POST request
         utils.log(f"Post {prepared_url} with timeout={settings.timeout}")
         headers = _get_http_headers()
-        response = requests.post(url, data=data, timeout=settings.timeout, headers=headers)
+        response = requests.post(
+            url, data=data, timeout=settings.timeout, headers=headers, **settings.requests_kwargs
+        )
         sc = response.status_code
 
         # log the response size and domain
