@@ -3,7 +3,9 @@ Download geospatial entities' geometries and attributes from OpenStreetMap.
 
 Retrieve points of interest, building footprints, or any other objects from
 OSM, including their geometries and attribute data, and construct a
-GeoDataFrame of them.
+GeoDataFrame of them. You can use this module to query for nodes, ways, and
+relations (the latter of type "multipolygon" or "boundary" only) by passing a
+dictionary of desired tags/values.
 """
 
 import logging as lg
@@ -63,7 +65,7 @@ def geometries_from_bbox(north, south, east, west, tags):
     Notes
     -----
     You can configure the Overpass server timeout, memory allocation, and
-    other custom settings via ox.config().
+    other custom settings via the `settings` module.
     """
     # convert bounding box to a polygon
     polygon = utils_geo.bbox_to_poly(north, south, east, west)
@@ -104,7 +106,7 @@ def geometries_from_point(center_point, tags, dist=1000):
     Notes
     -----
     You can configure the Overpass server timeout, memory allocation, and
-    other custom settings via ox.config().
+    other custom settings via the `settings` module.
     """
     # create bounding box from center point and distance in each direction
     north, south, east, west = utils_geo.bbox_from_point(center_point, dist)
@@ -149,7 +151,7 @@ def geometries_from_address(address, tags, dist=1000):
     Notes
     -----
     You can configure the Overpass server timeout, memory allocation, and
-    other custom settings via ox.config().
+    other custom settings via the `settings` module.
     """
     # geocode the address string to a (lat, lng) point
     center_point = geocoder.geocode(query=address)
@@ -162,7 +164,20 @@ def geometries_from_address(address, tags, dist=1000):
 
 def geometries_from_place(query, tags, which_result=None, buffer_dist=None):
     """
-    Create a GeoDataFrame of OSM entities within the boundaries of a place.
+    Create GeoDataFrame of OSM entities within boundaries of geocodable place(s).
+
+    The query must be geocodable and OSM must have polygon boundaries for the
+    geocode result. If OSM does not have a polygon for this place, you can
+    instead get geometries within it using the geometries_from_address
+    function, which geocodes the place name to a point and gets the geometries
+    within some distance of that point.
+
+    If OSM does have polygon boundaries for this place but you're not finding
+    it, try to vary the query string, pass in a structured query dict, or vary
+    the which_result argument to use a different geocode result. If you know
+    the OSM ID of the place, you can retrieve its boundary polygon using the
+    geocode_to_gdf function, then pass it to the geometries_from_polygon
+    function.
 
     Parameters
     ----------
@@ -193,7 +208,7 @@ def geometries_from_place(query, tags, which_result=None, buffer_dist=None):
     Notes
     -----
     You can configure the Overpass server timeout, memory allocation, and
-    other custom settings via ox.config().
+    other custom settings via the `settings` module.
     """
     # create a GeoDataFrame with the spatial boundaries of the place(s)
     if isinstance(query, (str, dict)):
@@ -205,7 +220,7 @@ def geometries_from_place(query, tags, which_result=None, buffer_dist=None):
     elif isinstance(query, list):
         # if it is a list, it contains multiple places to get
         gdf_place = geocoder.geocode_to_gdf(query, buffer_dist=buffer_dist)
-    else:
+    else:  # pragma: no cover
         raise TypeError("query must be dict, string, or list of strings")
 
     # extract the geometry from the GeoDataFrame to use in API query
@@ -246,7 +261,7 @@ def geometries_from_polygon(polygon, tags):
     Notes
     -----
     You can configure the Overpass server timeout, memory allocation, and
-    other custom settings via ox.config().
+    other custom settings via the `settings` module.
     """
     # verify that the geometry is valid and a Polygon/MultiPolygon
     if not polygon.is_valid:
@@ -359,6 +374,9 @@ def _create_gdf(response_jsons, polygon, tags):
         # Set to hold the unique IDs of elements that do not have tags
         untagged_element_ids = set()
 
+        # identify which relation types to parse to (multi)polygons
+        relation_types = {"boundary", "multipolygon"}
+
         # extract geometries from the downloaded osm data
         for response_json in response_jsons:
             # Parses the JSON of OSM nodes, ways and (multipolygon) relations
@@ -398,9 +416,9 @@ def _create_gdf(response_jsons, polygon, tags):
 
                 elif (
                     element["type"] == "relation"
-                    and element.get("tags").get("type") == "multipolygon"
+                    and element.get("tags").get("type") in relation_types
                 ):
-                    # Parse all multipolygon relations to multipolygons
+                    # parse relations to (multi)polygons
                     multipolygon = _parse_relation_to_multipolygon(
                         element=element, geometries=geometries
                     )
@@ -784,7 +802,7 @@ def _assemble_multipolygon_component_polygons(element, geometries):
     if merged_outer_linestrings.geom_type == "LineString":
         outer_polygons += polygonize(merged_outer_linestrings)
     elif merged_outer_linestrings.geom_type == "MultiLineString":
-        for merged_outer_linestring in list(merged_outer_linestrings):
+        for merged_outer_linestring in list(merged_outer_linestrings.geoms):
             outer_polygons += polygonize(merged_outer_linestring)
 
     # Merge inner linestring fragments.
@@ -795,7 +813,7 @@ def _assemble_multipolygon_component_polygons(element, geometries):
     if merged_inner_linestrings.geom_type == "LineString":
         inner_polygons += polygonize(merged_inner_linestrings)
     elif merged_inner_linestrings.geom_type == "MultiLineString":
-        for merged_inner_linestring in list(merged_inner_linestrings):
+        for merged_inner_linestring in merged_inner_linestrings.geoms:
             inner_polygons += polygonize(merged_inner_linestring)
 
     if not outer_polygons:
@@ -851,7 +869,7 @@ def _subtract_inner_polygons_from_outer_polygons(element, outer_polygons, inner_
         if outer_polygon.geom_type == "Polygon":
             outer_polygons_with_holes.append(outer_polygon)
         elif outer_polygon.geom_type == "MultiPolygon":
-            outer_polygons_with_holes.extend(list(outer_polygon))
+            outer_polygons_with_holes.extend(list(outer_polygon.geoms))
 
     # if only one polygon with holes was created, return that single polygon
     if len(outer_polygons_with_holes) == 1:
@@ -982,9 +1000,8 @@ def _filter_gdf_by_polygon_and_tags(gdf, polygon, tags):
         # remove columns of all nulls (created by discarded component geometries)
         gdf.dropna(axis="columns", how="all", inplace=True)
 
-        # reset the index keeping the unique ids
-        gdf.reset_index(inplace=True)
-        # rename the new 'index' column to 'unique_id'
-        gdf.rename(columns={"index": "unique_id"}, inplace=True)
-
+    # multi-index gdf by element_type and osmid then return
+    idx_cols = ["element_type", "osmid"]
+    if all(c in gdf.columns for c in idx_cols):
+        gdf = gdf.set_index(idx_cols)
     return gdf
